### Name: binPower
### Title: Power to reject a hypothesis using confidence intervals in
###   binomial testing
### Aliases: binPower binPowerI
### Keywords: htest

### ** Examples


# What is the probability to reject the null hypothesis
# H0: p >= 0.02 in order to show that the alternative
# hypothesis HA: p < 0.02 is very likely in the first
# example of if 200 seeds are taken from a seed lot and
# are checked for the proportion of defectives.
# We assume a true proportion under the alternative:
# p = 0.01, i.e. a absolute difference delta = 0.01 
# to the threshold proportion p.hyp=0.02.
# We can reject the null hypothesis if the threshold
# p.hyp=0.02 is excluded by an 95 percent upper bound of the 
# Clopper-Pearson CI. How big is power?

binPower(n=200, delta=0.01, p.hyp=0.02,
 alternative="less", method="CP")

# May be we assume a lower true proportion (we are
# satisfied also with the situation that we can only reject H0
# in case that the seed lot has a very high purity, e.g.
# only a proportion of 0.001 defectives )

binPower(n=200, delta=0.019, p.hyp=0.02,
 alternative="less", method="CP")

# Or we have to use a higher sample size:

binPower(n=600, delta=0.01, p.hyp=0.02,
 alternative="less", method="CP")




