### Name: nDesign
### Title: Find a number of groups, for which a pre-specified power is
###   reached, if the group size is fixed
### Aliases: nDesign
### Keywords: htest

### ** Examples


## We want to show that a proportion is smaller
## 0.005 (i.e. 0.5 per cent) with a power 
## of 0.80 (i.e. 80 per cent) if the unknown proportion
## in the population is 0.003 (i.e. 0.3 per cent),
## thus we want to detect a delta of 0.002.
## The Clopper Pearson CI shall be used. 
## The maximal group size because of limited
## sensitivity of assay might be s=20 and we
## can only afford to perform maximally 100 assays:

nDesign(nmax=100, s=20, delta=0.002, p.hyp=0.005,
 alternative="less", method="CP", power=0.8)

## we don't reach 80 per cent power but only 30 percent
## with n=100 (caution: power does not increase monotone)

## we might accept to show significant only for a 
## lower true proportion = 0.001 i.e we accept to be
## able to show significance only if true proportion 
## is delta=0.004 smaller than the threshold

nDesign(nmax=100, s=20, delta=0.004, p.hyp=0.005,
 alternative="less", method="CP", power=0.8)

## and we find an assay method with higher sensitivity,
## allowing to find identify a positive unit even in a
## bulk sample of size s=30, and use a less conservative
## confidence interval:

nDesign(nmax=100, s=30, delta=0.004, p.hyp=0.005,
 alternative="less", method="SOC", power=0.8)

nDesign(nmax=100, s=30, delta=0.004, p.hyp=0.005,
 alternative="less", method="Score", power=0.8)

## plot the results:

test<-nDesign(nmax=100, s=30, delta=0.004, p.hyp=0.005,
 alternative="less", method="CP", power=0.8)

plot(test)




